@@ -1,3 +1,24 @@
+// Metawidget ${project.version}
+//
+// This library is dual licensed under both LGPL and a commercial
+// license.
+//
+// LGPL: this library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
+// version 2.1 of the License, or (at your option) any later version.
+//
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+// Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public
+// License along with this library; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+// Commercial License: See http://metawidget.org for details
+
 var assert = require( 'assert' );
 var metawidget = require( 'metawidget' );
 
@@ -6,6 +27,8 @@ var metawidget = require( 'metawidget' );
 var simpleDocument = {
 	createElement: function( elementName ) {
 
+		var _eventListeners = [];
+
 		return {
 			nodeType: 1,
 			tagName: elementName.toUpperCase(),
@@ -56,6 +79,24 @@ var simpleDocument = {
 				}
 				return clone;
 			},
+			addEventListener: function( name, callback ) {
+				
+				_eventListeners.push( {
+					name: name,
+					callback: callback
+				} );
+			},
+			dispatchEvent: function( event ) {
+
+				for( var loop = 0, length = _eventListeners.length; loop < length; loop++ ) {
+					
+					var eventListener = _eventListeners[loop];
+					
+					if ( eventListener.name === event.name ) {
+						eventListener.callback( event );
+					}
+				}
+			},			
 			ownerDocument: this,
 			toString: function() {
 
@@ -94,7 +135,17 @@ var simpleDocument = {
 				return data;
 			}
 		}
-	}
+	},
+	createEvent: function() {
+
+		return {
+		
+			initEvent: function( name ) {
+
+				this.name = name;
+			}
+		};
+	}	
 };
 
 var element = simpleDocument.createElement( 'div' );
